/*
 * CODE REVISION NUMBER:
 *
 * The part after the first colon, except the last char, appears on the screen.
 * The part after the first underscore is the subrevision.
 * A second underscore marks a development version.
 */

#include "version.h"

const char rev[] = "$Revision: 7.16_1.1.3 241123 0424 $";
